def get_classes():

    from HeadphonesMonitor import HeadphonesMonitor
    from SoundVolumeMonitor import SoundVolumeMonitor
    from PhoneMonitor import PhoneMonitor
    return [HeadphonesMonitor,
            SoundVolumeMonitor,
            PhoneMonitor]



import __messages__
messages = [ m for m in dir(__messages__) if not m.startswith("__") ]

